//[mahjong-utils](../../../../index.md)/[mahjongutils.hanhu](../../index.md)/[ChildPoint](../index.md)/[Companion](index.md)/[Yakuman](-yakuman.md)

# Yakuman

[common]\
val [Yakuman](-yakuman.md): [ChildPoint](../index.md)
